#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""


M. Bernreuther

"""

import numpy as np

#------------------------------------------------------------------------------
# Adds an arrow to a Line2d object
#------------------------------------------------------------------------------
def draw_arrow(line, position=None, direction='rechts', size=15, color=None):
    '''
    Adds an arrow to a line.

    Parameters
    ----------
    line : Line2D object
        Line2D object.
    position : float, optional
	y position of the arrow. If None the y position will be the mean of y_data
        Default is None.
    direction : string, optional
        Allowed values: 'left' and 'right'. Default is 'right'
    size : float, optional
        Size of the arrow. Default is 15.
    color : string, optional
	Color of the arrow. Default is None, that is the color of the line will be used.

    Returns
    -------
    None.

    Example use case
    ----------------------
    import matplotlib.pyplot as plt
    from DrawArrows import draw_arrow
    
    line = plt.plot(xvector, yvector)[0]   # yields a Line2D object
    draw_arrow(line)

    '''
    
    if color is None:
        color = line.get_color()

    x_daten = line.get_xdata()
    y_daten = line.get_ydata()

    if position is None:
        position = y_daten.mean()
        
    # Get enxt appropriate index
    start_ind = np.argmin(np.abs(y_daten - position))
    
    if direction == 'rechts':
        end_ind = start_ind + 1
    else:
        end_ind = start_ind - 1

    line.axes.annotate('',
        xytext=(x_daten[start_ind], y_daten[start_ind]),
        xy=(x_daten[end_ind], y_daten[end_ind]),
        arrowprops = dict(arrowstyle = "->", color = color),
        size = size
    )
    return
